@@ -1,9 +1,10 @@
 /*
- * Copyright 2003-2004 The Apache Software Foundation.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -14,7 +15,7 @@
  * limitations under the License.
  */
 
-// $Id: Duration.java 226236 2005-06-17 03:10:33Z mrglavas $
+// $Id: Duration.java 446598 2006-09-15 12:55:40Z jeremias $
 
 package javax.xml.datatype;
 
@@ -86,17 +87,12 @@ import javax.xml.namespace.QName;
  * @author <a href="mailto:Joseph.Fialli@Sun.COM">Joseph Fialli</a>
  * @author <a href="mailto:Kohsuke.Kawaguchi@Sun.com">Kohsuke Kawaguchi</a>
  * @author <a href="mailto:Jeff.Suttor@Sun.com">Jeff Suttor</a>
- * @version $Revision: 226236 $, $Date: 2005-06-16 23:10:33 -0400 (Thu, 16 Jun 2005) $    
+ * @version $Revision: 446598 $, $Date: 2006-09-15 14:55:40 +0200 (Fri, 15 Sep 2006) $    
  * @see XMLGregorianCalendar#add(Duration)
  * @since 1.5
  */
 public abstract class Duration {
 		
-	/**
-	 * <p>Debugging <code>true</code> or <code>false</code>.</p> 
-	 */
-	private static final boolean DEBUG = true;
-
 	/**
 	 * <p>Return the name of the XML Schema date/time type that this instance 
 	 * maps to. Type is computed based on fields that are set,
