@@ -1,9 +1,10 @@
 /*
- * Copyright 2003-2005 The Apache Software Foundation.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -14,11 +15,15 @@
  * limitations under the License.
  */
 
-// $Id: QName.java 226225 2005-06-04 04:12:57Z mrglavas $
+// $Id: QName.java 446598 2006-09-15 12:55:40Z jeremias $
 
 package javax.xml.namespace;
 
+import java.io.IOException;
+import java.io.ObjectInputStream;
 import java.io.Serializable;
+import java.security.AccessController;
+import java.security.PrivilegedAction;
 
 import javax.xml.XMLConstants;
 
@@ -53,7 +58,7 @@ import javax.xml.XMLConstants;
  * <p><code>QName</code> is immutable.</p>
  *
  * @author <a href="mailto:Jeff.Suttor@Sun.com">Jeff Suttor</a>
- * @version $Revision: 226225 $, $Date: 2005-06-04 00:12:57 -0400 (Sat, 04 Jun 2005) $
+ * @version $Revision: 446598 $, $Date: 2006-09-15 14:55:40 +0200 (Fri, 15 Sep 2006) $
  * @see <a href="http://www.w3.org/TR/xmlschema-2/#QName">XML Schema Part2: Datatypes specification</a>
  * @see <a href="http://www.w3.org/TR/REC-xml-names/#ns-qualnames">Namespaces in XML</a>
  * @see <a href="http://www.w3.org/XML/xml-names-19990114-errata">Namespaces in XML Errata</a>
@@ -64,8 +69,39 @@ public class QName implements Serializable {
 
     /**
      * <p>Stream Unique Identifier.</p>
+     * 
+     * <p>To enable the compatibility <code>serialVersionUID</code>
+     * set the System Property
+     * <code>org.apache.xml.namespace.QName.useCompatibleSerialVersionUID</code>
+     * to a value of "1.0".</p>
      */
-    private static final long serialVersionUID = 4418622981026545151L;
+    private static final long serialVersionUID;
+    
+    /**
+     * <p>The original default Stream Unique Identifier.</p>
+     */
+    private static final long defaultSerialVersionUID = -9120448754896609940L;
+    
+    /**
+     * <p>The compatibility Stream Unique Identifier that was introduced
+     * with Java 5 SE SDK.</p>
+     */
+    private static final long compatabilitySerialVersionUID = 4418622981026545151L;
+    
+    static {
+        String compatPropValue = null;
+        try {
+            compatPropValue = (String)AccessController.doPrivileged(
+                    new PrivilegedAction() {
+                        public Object run() {
+                            return System.getProperty("org.apache.xml.namespace.QName.useCompatibleSerialVersionUID");
+                        }
+                    });
+        } 
+        catch (Exception e) {}
+        // If 1.0 use compatability serialVersionUID
+        serialVersionUID = !"1.0".equals(compatPropValue) ? defaultSerialVersionUID : compatabilitySerialVersionUID;
+    }
 
     /**
      * <p>Namespace URI of this <code>QName</code>.</p>
@@ -80,7 +116,7 @@ public class QName implements Serializable {
     /**
      * <p>prefix of this <code>QName</code>.</p>
      */
-    private final String prefix;
+    private String prefix;
     
     /**
      * <p><code>String</code> representation of this <code>QName</code>.</p>
@@ -442,4 +478,19 @@ public class QName implements Serializable {
             qNameAsString.substring(endOfNamespaceURI + 1),
             XMLConstants.DEFAULT_NS_PREFIX);
     }
+    
+    /*
+     * For old versions of QName which didn't have a prefix field,
+     * <code>ObjectInputStream.defaultReadObject()</code> will initialize
+     * the prefix to <code>null</code> instead of the empty string. This
+     * method fixes up the prefix field if it didn't exist in the serialized
+     * object.
+     */
+    private void readObject(ObjectInputStream in) 
+        throws IOException, ClassNotFoundException {
+        in.defaultReadObject();
+        if (prefix == null) {
+            prefix = XMLConstants.DEFAULT_NS_PREFIX;
+        }
+    }
 }
