@@ -1,9 +1,10 @@
 /*
- * Copyright 2003-2004 The Apache Software Foundation.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -13,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-// $Id: SchemaFactoryFinder.java 226247 2005-06-20 22:05:52Z mrglavas $
+// $Id: SchemaFactoryFinder.java 446598 2006-09-15 12:55:40Z jeremias $
 
 package javax.xml.validation;
 
@@ -33,17 +34,14 @@ import java.util.Properties;
  * Implementation of {@link SchemaFactory#newInstance(String)}.
  * 
  * @author <a href="Kohsuke.Kawaguchi@Sun.com">Kohsuke Kawaguchi</a>
- * @version $Revision: 226247 $, $Date: 2005-06-20 18:05:52 -0400 (Mon, 20 Jun 2005) $
+ * @version $Revision: 446598 $, $Date: 2006-09-15 14:55:40 +0200 (Fr, 15 Sep 2006) $
  * @since 1.5
  */
-class SchemaFactoryFinder  {
+final class SchemaFactoryFinder  {
 
     /** debug support code. */
     private static boolean debug = false;
-    /**
-     *<p> Take care of restrictions imposed by java security model </p>
-     */
-    private static SecuritySupport ss = new SecuritySupport();
+
     /**
      * <p>Cache properties for performance.</p>
      */
@@ -62,7 +60,9 @@ class SchemaFactoryFinder  {
     static {
         // Use try/catch block to support applets
         try {
-            debug = ss.getSystemProperty("jaxp.debug") != null;
+            String val = SecuritySupport.getSystemProperty("jaxp.debug");
+            // Allow simply setting the prop to turn on debug
+            debug = val != null && (! "false".equals(val));
         } catch (Exception _) {
             debug = false;
         }
@@ -104,7 +104,7 @@ class SchemaFactoryFinder  {
     
     private void debugDisplayClassLoader() {
         try {
-            if( classLoader == ss.getContextClassLoader() ) {
+            if( classLoader == SecuritySupport.getContextClassLoader() ) {
                 debugPrintln("using thread context class loader ("+classLoader+") for search");
                 return;
             }
@@ -136,10 +136,12 @@ class SchemaFactoryFinder  {
     public SchemaFactory newFactory(String schemaLanguage) {
         if(schemaLanguage==null)        throw new NullPointerException();
         SchemaFactory f = _newFactory(schemaLanguage);
-        if (f != null) {
-            debugPrintln("factory '" + f.getClass().getName() + "' was found for " + schemaLanguage);
-        } else {
-            debugPrintln("unable to find a factory for " + schemaLanguage);
+        if (debug) {
+            if (f != null) {
+                debugPrintln("factory '" + f.getClass().getName() + "' was found for " + schemaLanguage);
+            } else {
+                debugPrintln("unable to find a factory for " + schemaLanguage);
+            }
         }
         return f;
     }
@@ -157,14 +159,16 @@ class SchemaFactoryFinder  {
         
         // system property look up
         try {
-            debugPrintln("Looking up system property '"+propertyName+"'" );
-            String r = ss.getSystemProperty(propertyName);
-            if(r!=null) {
-                debugPrintln("The value is '"+r+"'");
+            if (debug) debugPrintln("Looking up system property '"+propertyName+"'" );
+            String r = SecuritySupport.getSystemProperty(propertyName);
+            if (r != null) {
+                if (debug) debugPrintln("The value is '"+r+"'");
                 sf = createInstance(r);
                 if(sf!=null)    return sf;
-            } else
+            } 
+            else if (debug) {
                 debugPrintln("The property is undefined.");
+            }
         } catch( Throwable t ) {
             if( debug ) {
                 debugPrintln("failed to look up system property '"+propertyName+"'" );
@@ -172,7 +176,7 @@ class SchemaFactoryFinder  {
             }
         }
 
-        String javah = ss.getSystemProperty( "java.home" );
+        String javah = SecuritySupport.getSystemProperty( "java.home" );
         String configFile = javah + File.separator +
         "lib" + File.separator + "jaxp.properties";
 
@@ -185,15 +189,15 @@ class SchemaFactoryFinder  {
                     if(firstTime){
                         File f=new File( configFile );
                         firstTime = false;
-                        if(ss.doesFileExist(f)){
-                            debugPrintln("Read properties file " + f);                                
-                            cacheProps.load(ss.getFileInputStream(f));
+                        if(SecuritySupport.doesFileExist(f)){
+                            if (debug) debugPrintln("Read properties file " + f);                                
+                            cacheProps.load(SecuritySupport.getFileInputStream(f));
                         }
                     }
                 }
             }
             factoryClassName = cacheProps.getProperty(propertyName);            
-            debugPrintln("found " + factoryClassName + " in $java.home/jaxp.properties"); 
+            if (debug) debugPrintln("found " + factoryClassName + " in $java.home/jaxp.properties"); 
 
             if (factoryClassName != null) {
                 sf = createInstance(factoryClassName);
@@ -233,9 +237,9 @@ class SchemaFactoryFinder  {
         Iterator sitr = createServiceFileIterator();
         while(sitr.hasNext()) {
             URL resource = (URL)sitr.next();
-            debugPrintln("looking into " + resource);
+            if (debug) debugPrintln("looking into " + resource);
             try {
-                sf = loadFromServicesFile(schemaLanguage,resource.toExternalForm(),ss.getURLInputStream(resource));
+                sf = loadFromServicesFile(schemaLanguage,resource.toExternalForm(),SecuritySupport.getURLInputStream(resource));
                 if(sf!=null)    return sf;
             } catch(IOException e) {
                 if( debug ) {
@@ -247,11 +251,11 @@ class SchemaFactoryFinder  {
         
         // platform default
         if (schemaLanguage.equals("http://www.w3.org/2001/XMLSchema")) {
-            debugPrintln("attempting to use the platform default XML Schema validator");
+            if (debug) debugPrintln("attempting to use the platform default XML Schema validator");
             return createInstance("org.apache.xerces.jaxp.validation.XMLSchemaFactory");
         }
         
-        debugPrintln("all things were tried, but none was found. bailing out.");
+        if (debug) debugPrintln("all things were tried, but none was found. bailing out.");
         return null;
     }
     
@@ -266,7 +270,7 @@ class SchemaFactoryFinder  {
      */
     private SchemaFactory createInstance( String className ) {
         try {
-            debugPrintln("instanciating "+className);
+            if (debug) debugPrintln("instanciating "+className);
             Class clazz;
             if( classLoader!=null )
                 clazz = classLoader.loadClass(className);
@@ -278,7 +282,7 @@ class SchemaFactoryFinder  {
             if( o instanceof SchemaFactory )
                 return (SchemaFactory)o;
             
-            debugPrintln(className+" is not assignable to "+SERVICE_CLASS.getName());
+            if (debug) debugPrintln(className+" is not assignable to "+SERVICE_CLASS.getName());
         } catch( Throwable t ) {
             debugPrintln("failed to instanciate "+className);
             if(debug)   t.printStackTrace();
@@ -301,30 +305,6 @@ class SchemaFactoryFinder  {
         protected abstract Object value();
     }
     
-    /**
-     * Looks up a value in a property file
-     * while producing all sorts of debug messages.
-     * 
-     * @return null
-     *      if there was an error.
-     */
-    private SchemaFactory loadFromProperty( String keyName, String resourceName, InputStream in )
-        throws IOException {
-        debugPrintln("Reading "+resourceName );
-        
-        Properties props=new Properties();
-        props.load(in);
-        in.close();
-        String factoryClassName = props.getProperty(keyName);
-        if(factoryClassName != null){
-            debugPrintln("found "+keyName+" = " + factoryClassName);
-            return createInstance(factoryClassName);
-        } else {
-            debugPrintln(keyName+" is not in the property file");
-            return null;
-        }
-    }
-    
     /**
      * Returns an {@link Iterator} that enumerates all 
      * the META-INF/services files that we care.
@@ -335,14 +315,14 @@ class SchemaFactoryFinder  {
                 protected Object value() {
                     ClassLoader classLoader = SchemaFactoryFinder.class.getClassLoader();
                     //return (ClassLoader.getSystemResource( SERVICE_ID ));
-                    return ss.getResourceAsURL(classLoader, SERVICE_ID);
+                    return SecuritySupport.getResourceAsURL(classLoader, SERVICE_ID);
                 }
             };
         } else {
             try {
                 //final Enumeration e = classLoader.getResources(SERVICE_ID);
-                final Enumeration e = ss.getResources(classLoader, SERVICE_ID);
-                if(!e.hasMoreElements()) {
+                final Enumeration e = SecuritySupport.getResources(classLoader, SERVICE_ID);
+                if(debug && !e.hasMoreElements()) {
                     debugPrintln("no "+SERVICE_ID+" file was found");
                 }
                 
@@ -361,8 +341,10 @@ class SchemaFactoryFinder  {
                     }
                 };
             } catch (IOException e) {
-                debugPrintln("failed to enumerate resources "+SERVICE_ID);
-                if(debug)   e.printStackTrace();
+                if (debug) {
+                    debugPrintln("failed to enumerate resources "+SERVICE_ID);
+                    e.printStackTrace();
+                }
                 return new ArrayList().iterator();  // empty iterator
             }
         }
@@ -371,7 +353,7 @@ class SchemaFactoryFinder  {
     /** Searches for a SchemaFactory for a given schema language in a META-INF/services file. */
     private SchemaFactory loadFromServicesFile(String schemaLanguage, String resourceName, InputStream in) {
 
-        debugPrintln("Reading "+resourceName );
+        if (debug) debugPrintln("Reading "+resourceName );
         
         // Read the service provider name in UTF-8 as specified in
         // the jar spec.  Unfortunately this fails in Microsoft
@@ -470,7 +452,7 @@ class SchemaFactoryFinder  {
         if( loader==null )  loader = ClassLoader.getSystemClassLoader();
         
         //URL it = loader.getResource(classnameAsResource);
-        URL it = ss.getResourceAsURL(loader, classnameAsResource);
+        URL it = SecuritySupport.getResourceAsURL(loader, classnameAsResource);
         if (it != null) {
             return it.toString();
         } else {
